/* gameprob.i - SWIG control file for the gameprob module
 *
 * Copyright (C) 2003  Jochen Voss.
 *
 * $Id: gameprob.i 5068 2003-07-19 12:43:00Z voss $ */

%module gameprob
%{
#include "gameprob.h"

static PyObject *wrap_param_name (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  int id;
  
  if (! PyArg_ParseTuple (args, "i", &id))  return NULL;
  ptr = find_parameter (id);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter id");
    return NULL;
  }
  if (! ptr->name) {
    PyErr_SetString(PyExc_ValueError, "parameter has no name");
    return NULL;
  }
  return  PyString_FromString (ptr->name);
}

static PyObject *wrap_param_min (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  int id;
  
  if (! PyArg_ParseTuple (args, "i", &id))  return NULL;
  ptr = find_parameter (id);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter id");
    return NULL;
  }
  return  PyFloat_FromDouble (ptr->min);
}

static PyObject *wrap_param_max (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  int id;
  
  if (! PyArg_ParseTuple (args, "i", &id))  return NULL;
  ptr = find_parameter (id);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter id");
    return NULL;
  }
  return  PyFloat_FromDouble (ptr->max);
}

static PyObject *wrap_param_default (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  int id;
  
  if (! PyArg_ParseTuple (args, "i", &id))  return NULL;
  ptr = find_parameter (id);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter id");
    return NULL;
  }
  return  PyFloat_FromDouble (ptr->default_value);
}

static PyObject *wrap_param_board (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  int id;
  
  if (! PyArg_ParseTuple (args, "i", &id))  return NULL;
  ptr = find_parameter (id);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter id");
    return NULL;
  }
  return  PyInt_FromLong (ptr->board);
}

static PyObject *wrap_find_param_by_name (PyObject *self, PyObject *args) {
  struct param_info *ptr;
  const char *name;
  
  if (! PyArg_ParseTuple (args, "s", &name))  return NULL;
  ptr = find_param_by_name (name);
  if (! ptr) {
    PyErr_SetString(PyExc_KeyError, "invalid parameter name");
    return NULL;
  }
  return  PyInt_FromLong (ptr->id);
}
%}

extern  void  register_parameter (int id, const char *name);
extern  void  set_param (int id, double val);
extern  double  get_param (int id);
%native(param_name) wrap_param_name;
%native(param_board) wrap_param_board;
%native(param_min) wrap_param_min;
%native(param_max) wrap_param_max;
%native(param_default) wrap_param_default;
%native(find_param_by_name) wrap_find_param_by_name;


enum result { res_BLACK, res_WHITE, res_JIGO };

extern void register_game (int id, int black, int white, int board,
			   int hc, int komi, int with_jigo,
			   const char *res);
extern  double  probability (int black, int white, int board,
			     int hc, int komi, int with_jigo,
			     enum result res);
extern  double  game_prob (int game);
extern  int  applies_to (int param, int game);

%init %{
  init_parameters ();
%}
